@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Find the top repeated note phrases of a MIDI file
 
-our $VERSION = '0.05';
+our $VERSION = '0.0501';
 
 use Moo;
 use strictures 2;
@@ -155,7 +155,7 @@ sub process {
         next unless @events && defined $track_channel;
 
         $i++;
-        $analysis .= "$t $i. channel: $track_channel\n";
+        $analysis .= "Track $i. Channel: $track_channel\n";
 
         # Declare the notes to inspect
         my $text = '';
@@ -394,7 +394,7 @@ MIDI::Ngram - Find the top repeated note phrases of a MIDI file
 
 =head1 VERSION
 
-version 0.05
+version 0.0501
 
 =head1 SYNOPSIS
 
